<%@ Page Language="VB" Debug="True" %>
<%@ import Namespace="System.Diagnostics" %>
<%@ import Namespace="System.Drawing" %>
<%@ import Namespace="Microsoft.Win32" %>
<%@ import Namespace="System.Data" %>
<%@ Register TagPrefix="rw" Namespace="rw" Assembly="eventlogdatasource" %>

<script runat="server">

    Sub Page_Load(ByVal sender As Object, ByVal e As EventArgs)
        If Not Page.IsPostBack Then
            EnumerateLogs()
            Dim liSystem As ListItem = lstLog.Items.FindByText("System")
            If (Not liSystem Is Nothing) Then liSystem.Selected = True
            ' default sort order by time with latest first
            GridView1.Sort("TimeGenerated", SortDirection.Descending)
        End If
    End Sub

    Sub EnumerateLogs()
        Dim regKey As RegistryKey
        regKey = Registry.LocalMachine.OpenSubKey("system\currentcontrolset\services\eventlog", True)
        Dim arrSubKeys() As String = regKey.GetSubKeyNames()
        regKey.Close()
        Dim subkey As String
        lstLog.Items.Clear()
        For Each subkey In arrSubKeys
            lstLog.Items.Add(subkey)
        Next
    End Sub

    Sub btnClear_OnClick(ByVal sender As Object, ByVal e As EventArgs)
        'Clear all of the event log entries
        Dim objEventLog As New EventLog(lstLog.SelectedValue)
        objEventLog.Clear()
    End Sub

    Protected Sub GridView1_RowDataBound(ByVal sender As Object, ByVal e As System.Web.UI.WebControls.GridViewRowEventArgs)
        If (e.Row.RowType = DataControlRowType.DataRow) Then
            Dim entry As DataRowView = CType(e.Row.DataItem, DataRowView)
            If (entry IsNot Nothing) Then
                Select Case entry("EntryType")
                    Case "Error"
                        e.Row.Cells(0).BackColor = Color.OrangeRed
                        e.Row.Cells(0).ForeColor = Color.White
                    Case "Warning"
                        e.Row.Cells(0).BackColor = Color.Yellow
                End Select
                If entry("UserName") Is Nothing Then
                    entry("UserName") = "N/A"
                End If
            End If
        End If
    End Sub
    
    Protected Sub eventlogdatasource1_Selected(ByVal sender As Object, ByVal e As rw.EventlogDataSourceStatusEventArgs)
        If(e.Exception IsNot Nothing) Then
            lblError.Text = e.Exception.Message
            e.ExceptionHandled = True
        End If
    End Sub
</script>
<html>
<head>
    <title>Event log viewer</title>
    <link href="eventlog.css" type="text/css" rel="stylesheet" />
</head>
<body>
    <form runat="server">
        <h1>Event Log Viewer
        </h1>
        <asp:RadioButtonList id="lstLog" runat="server" RepeatDirection="Horizontal" 
        AutoPostBack="True" >
            <asp:ListItem Value="Application">Application</asp:ListItem>
            <asp:ListItem Value="Security">Security</asp:ListItem>
            <asp:ListItem Value="System" Selected="True" >System</asp:ListItem>
        </asp:RadioButtonList>
        <hr />
        <asp:Label ID="lblError" runat="server" EnableViewState="False" ForeColor="Red"></asp:Label>
        <br />
        <asp:GridView id="GridView1" runat="server" Font-Size="X-Small" 
        DataSourceID="eventlogdatasource1"
        AutoGenerateColumns="False" AllowPaging="True" PageSize="20" AllowSorting="True"
        OnRowDataBound="GridView1_RowDataBound" >
            <HeaderStyle cssclass="headerstyle"/>
            <AlternatingRowStyle cssclass="altstyle"/>
            <RowStyle cssclass="itemstyle"/>
            <Columns>
                <asp:BoundField DataField="EntryType" HeaderText="Type" SortExpression="EntryType" />
                <asp:BoundField DataField="TimeGenerated" DataFormatString="{0:d}" 
                    HtmlEncode="False" HeaderText="Date" SortExpression="TimeGenerated" />
                <asp:BoundField DataField="TimeGenerated" DataFormatString="{0:T}" 
                    HtmlEncode="False" HeaderText="Time" SortExpression="TimeGenerated"/>
                <asp:BoundField DataField="Source" HeaderText="Source" SortExpression="Source" />
                <asp:BoundField DataField="UserName" HeaderText="User" SortExpression="UserName" />
                <asp:BoundField DataField="MachineName" HeaderText="Computer" SortExpression="MachineName" />
                <asp:TemplateField>
                    <ItemTemplate>
                        <asp:HyperLink ID="HyperLink1" runat="server" Text="details"
                        NavigateUrl='<%# Eval("Index", "detail.aspx?Index={0}" & "&logName=" & lstLog.SelectedValue) %>' >
                        </asp:HyperLink>
                    </ItemTemplate>
                </asp:TemplateField>
           </Columns>
        </asp:GridView>
        <rw:EventlogDataSource runat="server" ID="eventlogdatasource1" 
        OnSelected="eventlogdatasource1_Selected" >
        <Parameters>
            <asp:ControlParameter Name="EventlogName" Type="String" ControlID="lstLog"
                PropertyName="SelectedValue" />
        </Parameters>
        </rw:EventlogDataSource>
        <hr />
        <asp:button id="btnClear" onclick="btnClear_OnClick" runat="server" 
        Text="Clear Event Log" OnClientClick="return confirm('Are you sure?');"></asp:button>
    </form>
</body>
</html>
