Imports Microsoft.VisualBasic
Imports System.Web.UI
Imports System.Web.UI.Webcontrols
Imports System.Collections.Specialized
Imports System.ComponentModel
Imports System.ComponentModel.Design

Namespace rw
    <DefaultProperty("Parameters"), _
    ParseChildren(True), _
    PersistChildren(False)> _
    Public Class EventlogDataSource
        Inherits DataSourceControl

        Private _eventlogView As EventlogDataSourceView
        Private ReadOnly Property EventlogView() As EventlogDataSourceView
            Get
                If (_eventlogView Is Nothing) Then
                    _eventlogView = New EventlogDataSourceView(Me, "System")
                End If
                Return _eventlogView
            End Get
        End Property

        Private _parameters As ParameterCollection

        <PersistenceModeAttribute(PersistenceMode.InnerProperty)> _
        Public ReadOnly Property Parameters() As ParameterCollection
            Get
                If (_parameters Is Nothing) Then
                    _parameters = New ParameterCollection()
                    AddHandler _parameters.ParametersChanged, AddressOf OnParametersChanged
                    If (IsTrackingViewState) Then
                        CType(_parameters, IStateManager).TrackViewState()
                    End If
                End If
                Return _parameters
            End Get
        End Property

        Public Function GetEventlogName() As String
            ' The event log name is passed as a parameter
            If (_parameters IsNot Nothing) Then
                Dim eventlogName As Parameter = _parameters("EventlogName")
                If (eventlogName IsNot Nothing) Then
                    Dim parameterValues As IOrderedDictionary = _parameters.GetValues(Context, Me)
                    Return parameterValues(eventlogName.Name)
                End If
            End If
            Return "System"
        End Function

        Protected Overrides Function GetView(ByVal viewName As String) As System.Web.UI.DataSourceView
            If (String.IsNullOrEmpty(viewName) Or _
                (String.Compare(viewName, "DefaultViewName", True) = 0)) Then
                Return EventlogView
            End If
            Throw New ArgumentOutOfRangeException("viewName")
        End Function

        Protected Overrides Function GetViewNames() As System.Collections.ICollection
            Dim names() As String = {"DefaultViewName"}
            Return names
        End Function

        Public Event Selected As EventlogDataSourceStatusEventHandler
        Public Sub OnSelected(ByVal e As EventlogDataSourceStatusEventArgs)
            RaiseEvent Selected(Me, e)
        End Sub

        Protected Overrides Sub LoadViewState(ByVal savedState As Object)
            Dim baseState As Object = Nothing
            If (savedState IsNot Nothing) Then
                Dim p As Pair = CType(savedState, Pair)
                baseState = p.First
                If (p.Second IsNot Nothing) Then
                    CType(Parameters, IStateManager).LoadViewState(p.Second)
                End If
            End If
            MyBase.LoadViewState(baseState)
        End Sub

        Protected Overrides Sub OnInit(ByVal e As System.EventArgs)
            AddHandler Page.LoadComplete, New EventHandler(AddressOf Me.OnPageLoadComplete)
        End Sub

        Private Sub OnPageLoadComplete(ByVal sender As Object, ByVal e As EventArgs)
            If (_parameters IsNot Nothing) Then
                _parameters.UpdateValues(Context, Me)
            End If
        End Sub

        Private Sub OnParametersChanged(ByVal sender As Object, ByVal e As EventArgs)
            EventlogView.RaiseChangedEvent()
        End Sub

        Protected Overrides Function SaveViewState() As Object
            Dim baseState As Object = MyBase.SaveControlState()
            Dim parameterState As Object = Nothing
            If (_parameters IsNot Nothing) Then
                parameterState = CType(_parameters, IStateManager).SaveViewState()
            End If
            If (baseState IsNot Nothing Or parameterState IsNot Nothing) Then
                Return New Pair(baseState, parameterState)
            End If
            Return Nothing
        End Function

        Protected Overrides Sub TrackViewState()
            MyBase.TrackViewState()
            If (_parameters IsNot Nothing) Then
                CType(_parameters, IStateManager).TrackViewState()
            End If
        End Sub

    End Class

End Namespace
